@@ -12,18 +12,19 @@ from stl_sdk.atlantis.retry import retry
 class AtlantisClient:
     """Cliente HTTP para comunicação com Atlantis
 
-    :param str atlantis_url: Endereço da API do serviço Atlantis
+    :param str url: Endereço da API do serviço Atlantis
     :param str client_id: ID do cliente cadastrado no Atlantis
     :param str client_secret: Secret do cliente cadastrado no Atlantis
     """
+    url = None
+    client_id = None
+    client_secret = None
 
-    def __init__(self, client_id=None, client_secret=None, atlantis_url=None):
-        self.atlantis_url = atlantis_url.strip('/') if atlantis_url else None
+    def __init__(self, url, client_id, client_secret=None):
+        self.url = url.strip('/')
         self.client_id = client_id
         self.client_secret = client_secret
-
-        if atlantis_url:
-            self._set_openid_configuration()
+        self._set_openid_configuration()
 
     def _set_openid_configuration(self):
         self.configuration = self.get_openid_configuration()
@@ -35,7 +36,7 @@ class AtlantisClient:
         :rtype: dict
         """
         try:
-            response = requests.get('{}/.well-known/openid-configuration'.format(self.atlantis_url))
+            response = requests.get('{}/.well-known/openid-configuration'.format(self.url))
             response.raise_for_status()
             return response.json()
         except HTTPError as error:
@@ -133,7 +134,7 @@ class AtlantisClient:
         """
         try:
             response = requests.post(
-                '{}/api/introspect-token'.format(self.atlantis_url),
+                '{}/api/introspect-token'.format(self.url),
                 data={
                     'token': access_token,
                     'token_type_hint': 'access_token',
@@ -160,7 +161,7 @@ class AtlantisClient:
         """
         try:
             response = requests.post(
-                '{}/api/introspect-apikey'.format(self.atlantis_url),
+                '{}/api/introspect-apikey'.format(self.url),
                 data={
                     'apikey': api_key,
                     'client_id': self.client_id,
