@@ -21,18 +21,18 @@ class AtlantisClientFlask(AtlantisClient):
     """
 
     def __init__(self, app=None):
-        self.app = app
         if app is not None:
             self.init_app(app)
-        super().__init__()
 
     def init_app(self, app):
-        self.atlantis_url = app.config['ATLANTIS_URL']
-        self.client_id = app.config['ATLANTIS_CLIENT_ID']
-        self.client_secret = app.config.get('ATLANTIS_CLIENT_SECRET')
+        if app.config['ATLANTIS_URL'] is None:
+            raise InvalidInitParameters('Missing ATLANTIS_URL on AtlantisClientFlask initialization.')
 
-        if self.atlantis_url is None:
-            raise InvalidInitParameters('Missing ATLANTIS_URL on AtlantisClient initialization.')
+        if app.config['ATLANTIS_CLIENT_ID'] is None:
+            raise InvalidInitParameters('Missing ATLANTIS_CLIENT_ID on AtlantisClientFlask initialization.')
 
-        if self.client_id is None:
-            raise InvalidInitParameters('Missing ATLANTIS_CLIENT_ID on AtlantisClient initialization.')
+        super().__init__(
+            app.config['ATLANTIS_URL'],
+            app.config['ATLANTIS_CLIENT_ID'],
+            client_secret=app.config.get('ATLANTIS_CLIENT_SECRET')
+        )
\ No newline at end of file
